use std::thread;
use std::time::Duration;

use xcb::x;

use systemstat::{saturating_sub_bytes, Platform, System};

use chrono::prelude::*;

fn date_block() -> String {
    Local::now().format("%A %d %B | %H:%M").to_string()
}

fn mem_block() -> String {
    let sys = System::new();

    if let Ok(mem) = sys.memory() {
        format!("{}", saturating_sub_bytes(mem.total, mem.free))
    } else {
        "".to_string()
    }
}

fn main() -> xcb::Result<()> {
    let (conn, screen_num) = xcb::Connection::connect(None)?;

    // Fetch the `x::Setup` and get the main `x::Screen` object.
    let setup = conn.get_setup();
    let screen = setup.roots().nth(screen_num as usize).unwrap();

    loop {
        let status_bar = format!(" {} | {} ", mem_block(), date_block());

        conn.send_request(&x::ChangeProperty {
            mode: x::PropMode::Replace,
            window: screen.root(),
            property: x::ATOM_WM_NAME,
            r#type: x::ATOM_STRING,
            data: status_bar.as_bytes(),
        });

        conn.flush()?;

        thread::sleep(Duration::from_secs(1));
    }
}
